#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-lib
version:              1.4.0
visibility:           public
id:                   clash-lib-1.4.0-EhR2dudkQOM7ZYov1kvrpG
key:                  clash-lib-1.4.0-EhR2dudkQOM7ZYov1kvrpG
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2019, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - As a library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * The CoreHW internal language: SystemF + Letrec + Case-decomposition

    * The normalisation process that brings CoreHW in a normal form that can be
    converted to a netlist

    * Blackbox/Primitive Handling


    Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

    * <https://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

    * <https://github.com/christiaanb/Idris-dev Idris Frontend>


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  7dc44435406396ef5c081fdba55854d5
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation.ClashLib Clash.Backend
    Clash.Backend.SystemVerilog Clash.Backend.VHDL
    Clash.Backend.Verilog Clash.Core.DataCon Clash.Core.EqSolver
    Clash.Core.Evaluator.Types Clash.Core.FreeVars Clash.Core.Literal
    Clash.Core.Name Clash.Core.PartialEval
    Clash.Core.PartialEval.AsTerm Clash.Core.PartialEval.Monad
    Clash.Core.PartialEval.NormalForm Clash.Core.Pretty
    Clash.Core.Subst Clash.Core.Term Clash.Core.TermInfo
    Clash.Core.TermLiteral Clash.Core.TermLiteral.TH
    Clash.Core.Termination Clash.Core.TyCon Clash.Core.Type
    Clash.Core.TysPrim Clash.Core.Util Clash.Core.Var Clash.Core.VarEnv
    Clash.Debug Clash.Driver Clash.Driver.Manifest Clash.Driver.Types
    Clash.Edalize.Edam Clash.Netlist Clash.Netlist.BlackBox
    Clash.Netlist.BlackBox.Parser Clash.Netlist.BlackBox.Types
    Clash.Netlist.BlackBox.Util Clash.Netlist.Id
    Clash.Netlist.Id.Common Clash.Netlist.Id.Internal
    Clash.Netlist.Id.SystemVerilog Clash.Netlist.Id.VHDL
    Clash.Netlist.Id.Verilog Clash.Netlist.Types Clash.Netlist.Util
    Clash.Normalize Clash.Normalize.DEC
    Clash.Normalize.PrimitiveReductions Clash.Normalize.Strategy
    Clash.Normalize.Transformations Clash.Normalize.Types
    Clash.Normalize.Util Clash.Pretty Clash.Primitives.DSL
    Clash.Primitives.GHC.Int Clash.Primitives.GHC.Literal
    Clash.Primitives.GHC.Word Clash.Primitives.Intel.ClockGen
    Clash.Primitives.Sized.ToInteger Clash.Primitives.Sized.Vector
    Clash.Primitives.Types Clash.Primitives.Util
    Clash.Primitives.Verification Clash.Rewrite.Combinators
    Clash.Rewrite.Types Clash.Rewrite.Util Clash.Rewrite.WorkFree
    Clash.Unique Clash.Util Clash.Util.Graph Clash.Util.Interpolate
    Data.Text.Prettyprint.Doc.Extra

hidden-modules:
    Clash.Annotations.TopEntity.Extra Control.Applicative.Extra
    Data.Aeson.Extra Data.List.Extra Data.Map.Ordered.Extra
    Data.Primitive.ByteArray.Extra Data.Semigroup.Monad.Extra
    Data.Set.Ordered.Extra GHC.BasicTypes.Extra GHC.SrcLoc.Extra
    Paths_clash_lib

import-dirs:          /usr/lib/ghc-8.10.4/site-local/clash-lib-1.4.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/clash-lib-1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/clash-lib-1.4.0
hs-libraries:         HSclash-lib-1.4.0-EhR2dudkQOM7ZYov1kvrpG
depends:
    aeson-1.5.6.0-Gx77yI4aGhT9SDRJjDxR53
    aeson-pretty-0.8.8-A205tFKe7cI5MDRQuhSOae
    ansi-terminal-0.11-sYFHbiAEH84KFYZWhhTVC array-0.5.4.0
    attoparsec-0.13.2.5-AaEkuqZ31Ae8OJbD4JckmF base-4.14.1.0
    base16-bytestring-1.0.1.0-AbPDWkfzNhSEnvVrlUMkkD binary-0.8.8.0
    bytestring-0.10.12.0 clash-prelude-1.4.0-AC7tGK0aiR040Y7NwKHiEb
    concurrent-supply-0.1.8-Hfgdp3lM2Eb5HSwsvvn7ZC containers-0.6.2.1
    cryptohash-sha256-0.11.102.0-G9BAkNxhGn8LbpS4qCcTKj
    data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV deepseq-1.4.4.0
    directory-1.3.6.0 dlist-1.0-KFY6kePYM7gDQLIElBL83C
    errors-2.3.0-1jMMqiGok7nGSgO7igf65q exceptions-0.10.4
    extra-1.7.9-7fWXSNe9CIi5aPwdrWaSKi filepath-1.4.2.1 ghc-8.10.4
    ghc-boot-th-8.10.4 hashable-1.3.1.0-AFm7ygY4MxA76FjadItoSM
    haskell-src-meta-0.8.7-2OIYbpsP57HBtm3Guod2DB
    hint-0.9.0.4-DojTc9DFMqGCukI2KMkJ7c integer-gmp-1.0.3.0
    interpolate-0.2.1-JutdJVW3hPPHvuXCGvKVm7
    lens-4.19.2-CNVQVx1PKTiBoGhbS5k7vB mtl-2.2.2
    ordered-containers-0.2.2-GyU6swLq6k0DcCVw8rbPro
    parsers-0.12.10-G218PQbihVULRdAXGmHIMT
    pretty-show-1.10-EhdS2ToA2sEFyivshN51pj
    prettyprinter-1.7.0-JGvubQAa1CbGpzg9NdJeSn
    primitive-0.7.1.0-4GZ1AhedCql8LaKJmXLDHZ process-1.6.9.0
    reducers-3.12.3-K8FSXQunHtI8xwcoh4ie2C template-haskell-2.16.0.0
    temporary-1.3-LPYnz02GpZeCjglGSTWgz8
    terminal-size-0.3.2.1-HihNy0RThZk4O1UkYpAxTd text-1.2.4.1
    text-show-3.9-GFgg3fZAOty2v5qY68bVZc time-1.9.3
    transformers-0.5.6.2 trifecta-2.1.1-2P7AN1PVzJ0CLW1dqwDBqE
    unordered-containers-0.2.13.0-Dm1EWWGKu5F1HgehuVxZbu
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.2.0-jK90aUeXx6Ehemvl3B500
    vector-binary-instances-0.2.5.1-Bbhp9CKslFJHBLPg86EClv

haddock-interfaces:   /usr/share/doc/haskell-clash-lib/html/clash-lib.haddock
haddock-html:         /usr/share/doc/haskell-clash-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

